FloatingNode class

Inheritance

Constructors

FloatingNode({String? id, Key? key, Offset initPosition = const Offset(100, 100), Size initSize = const Size(200, 200), BlueprintController? blueprint, NodeWidget<FloatingNodeController>? child, int priority = 99999, Size minSize = const Size(100, 100), bool focusEnabled = true, Constraint constraint = Constraint.NONE, bool sizeFixed = true})
const

Properties

blueprint BlueprintController?
finalinherited
child NodeWidget<FloatingNodeController>?
This is the child widget of the node
finalinherited
clipBehavior Clip?
finalinherited
constraint Constraint
final
controller FloatingNodeController
no setterinherited
focusEnabled bool
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id String?
Unique id for the node controller, it's optional to assign it and it's auto generated if not assigned in the constructor.
finalinherited
init FloatingNodeController
no setteroverride
initPosition Offset
finalinherited
initSize Size
finalinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
minSize Size
finalinherited
priority int
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeFixed bool
final
tag String?
no setterinherited

Methods

build(BuildContext context) Widget
inherited
builder(FloatingNodeController controller) Widget
override
copyWith({String? id, NodeWidget<FloatingNodeController>? child, Offset? initPosition, Size? initSize, BlueprintController? blueprint, int? priority, bool? focusEnabled, Constraint? constraint, bool? sizeFixed}) FloatingNode
override
createElement() → GetWidgetCacheElement
Inflates this configuration to a concrete instance.
inherited
createWidgetCache() → WidgetCache<GetWidgetCache>
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
dispose() Future<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(BuildContext context) → void
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited