FloatingNode class
Constructors
-
FloatingNode({String? id, Key? key, Offset initPosition = const Offset(100, 100), Size initSize = const Size(200, 200), BlueprintController? blueprint, NodeWidget<FloatingNodeController>? child, int priority = 99999, Size minSize = const Size(100, 100), bool focusEnabled = true, Constraint constraint = Constraint.NONE, bool sizeFixed = true})
-
const
Methods
-
build(BuildContext context)
→ Widget
-
inherited
-
builder(FloatingNodeController controller)
→ Widget
-
override
-
copyWith({String? id, NodeWidget<FloatingNodeController>? child, Offset? initPosition, Size? initSize, BlueprintController? blueprint, int? priority, bool? focusEnabled, Constraint? constraint, bool? sizeFixed})
→ FloatingNode
-
override
-
createElement()
→ GetWidgetCacheElement
-
Inflates this configuration to a concrete instance.
inherited
-
createWidgetCache()
→ WidgetCache<GetWidgetCache>
-
inherited
-
debugDescribeChildren()
→ List<DiagnosticsNode>
-
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(DiagnosticPropertiesBuilder properties)
→ void
-
Add additional properties associated with the node.
inherited
-
dispose()
→ Future<void>
-
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(BuildContext context)
→ void
-
inherited
-
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style})
→ DiagnosticsNode
-
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString({DiagnosticLevel minLevel = DiagnosticLevel.info})
→ String
-
A string representation of this object.
inherited
-
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65})
→ String
-
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug})
→ String
-
Returns a one-line detailed description of the object.
inherited
-
toStringShort()
→ String
-
A short, textual description of this widget.
inherited